@@ -11,8 +11,8 @@ namespace torrent::net {
 
 class LIBTORRENT_EXPORT Resolver {
 public:
-  typedef std::function<void (c_sin_shared_ptr, c_sin6_shared_ptr, int)> both_callback;
-  typedef std::function<void (c_sa_shared_ptr, int)>                     single_callback;
+  using both_callback   = std::function<void(c_sin_shared_ptr, c_sin6_shared_ptr, int)>;
+  using single_callback = std::function<void(c_sa_shared_ptr, int)>;
 
   Resolver() = default;
   ~Resolver() = default;
